Backers who have funded Weblate
+++++++++++++++++++++++++++++++

List of Weblate supporters:

* Yashiro Ccs
* Cheng-Chia Tseng
* Timon Reinhard
* `Cassidy James <https://cassidyjames.com/>`_
* Loic Dachary
* Marozed
* https://freedombox.org/
* `GNU Solidario (GNU Health) <https://www.gnuhealth.org/>`_
* `BallotReady <https://www.ballotready.org>`_
* Richard Nespithal
* MyExpenses.Mobi

Do you want to be in the list? Please see options on the `Donate to Weblate <https://weblate.org/donate/>`_.
